import { world, system, EntityEquippableComponent, EquipmentSlot, ItemStack } from "@minecraft/server";
import { ActionFormData } from '@minecraft/server-ui'

world.afterEvents.itemUseOn.subscribe( on =>{
	try{
		let p = on.source;
		let item = on.itemStack;
		let lore = item.getLore()[0];
		let block = on.block

		if(lore.includes("Furrowing I")){
			p.runCommandAsync(`fill ${block.x-1} ${block.y} ${block.z-1} ~1~~1 farmland [] replace grass`)
			p.runCommandAsync(`fill ${block.x-1} ${block.y} ${block.z-1} ~1~~1 farmland [] replace grass`)
		}
		if(lore.includes("Furrowing II")){
			p.runCommandAsync(`fill ${block.x-2} ${block.y} ${block.z-2} ~2~~2 farmland [] replace grass`)
			p.runCommandAsync(`fill ${block.x-2} ${block.y} ${block.z-2} ~2~~2 farmland [] replace dirt`)
		}
		if(lore.includes("Furrowing III")){
			p.runCommandAsync(`fill ${block.x-3} ${block.y} ${block.z-3} ~3~~3 farmland [] replace grass`)
			p.runCommandAsync(`fill ${block.x-3} ${block.y} ${block.z-3} ~3~~3 farmland [] replace dirt`)
		}
	}catch(e){
		
	}
})


system.runInterval(() =>{
	try{
		let w = world.getDimension("overworld"); 

		for (let p of world.getPlayers()) {
			if (p.hasTag("interact")){
				EnchantedForm(p);
				p.removeTag("interact")
			}
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot);
			if(item){
				let lore = item.getLore()
				if (lore[0].includes("Haste I")){
					p.runCommandAsync(`effect @s haste 1 0 true`)
				}
				if (lore[0].includes("Haste II")){
					p.runCommandAsync(`effect @s haste 1 1 true`)
				}
				if (lore[0].includes("Haste III")){
					p.runCommandAsync(`effect @s haste 1 2 true`)
				}
			}
		}
	}
	catch(e){
	}

})

let hit = 0;

world.afterEvents.entityHurt.subscribe( hurt =>{
	try{
		let eHurt = hurt.hurtEntity;
		let damaging = hurt.damageSource.damagingEntity;

		if (damaging.typeId == "minecraft:player"){
			let item = damaging.getComponent("inventory").container.getItem(damaging.selectedSlot);
			if(item){
				let lore = item.getLore()
				if (lore[0].includes("Poison")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Poison")+7,lore[0].indexOf(" ",lore[0].indexOf("Poison")+7)))
					eHurt.runCommandAsync(`effect @s poison ${level*3} ${level-1}`)
				}
				if (lore[0].includes("Levitating")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Levitating")+11,lore[0].indexOf(" ",lore[0].indexOf("Levitating")+11)))
					eHurt.runCommandAsync(`effect @s levitation 2 ${(level*2)+3}`)
				}
				if (lore[0].includes("Vampire")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Vampire")+10,lore[0].indexOf(" ",lore[0].indexOf("Vampire")+10)))
					damaging.runCommandAsync(`effect @s regeneration ${level+2} ${level-1}`)
				}
				if (lore[0].includes("Wither")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Wither")+10,lore[0].indexOf(" ",lore[0].indexOf("Wither")+10)))
					eHurt.runCommandAsync(`effect @s wither ${level+2} ${level-1}`)
				}
				if (lore[0].includes("Ice Aspect")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Ice Aspect")+8,lore[0].indexOf(" ",lore[0].indexOf("Ice Aspect")+8)))
					eHurt.runCommandAsync(`effect @s slowness ${level*2} ${level}`)
				}
				if (lore[0].includes("Weakness")){
					let level = enchantedLevel(lore[0].substring(lore[0].indexOf("Ice Aspect")+8,lore[0].indexOf(" ",lore[0].indexOf("Weakness")+8)))
					eHurt.runCommandAsync(`effect @s weakness ${level*2} ${level}`)
				}

			}
		}
	}
	catch(e){
	}
})

world.afterEvents.entityHitBlock.subscribe( v=>{
	try{
		let block = v.hitBlock;

		let p = v.damagingEntity;

		let id = block.typeId;

		let ore =[
			"iron_ore",
			"gold_ore",
			"copper_ore",
			"rodio_ore",
			"platino_ore",
			"ambar_ore",
			"uranium_ore"
			]

		if(!id.includes(ore)){
			p.removeTag("iron");
			p.removeTag("gold");
			p.removeTag("copper");
			p.removeTag("ambar");
			p.removeTag("uranium");
			p.removeTag("rodio");
			p.removeTag("platino")
		}

		if(id.includes("iron_ore")){
			p.runCommandAsync(`tag @s add iron`)
		}
		if(id.includes("gold_ore")){
			p.runCommandAsync(`tag @s add gold`)
		}
		if(id.includes("copper_ore")){
			p.runCommandAsync(`tag @s add copper`)
		}
		if(id.includes("platino_ore")){
			p.runCommandAsync(`tag @s add platino`)
		}
		if(id.includes("rodio_ore")){
			p.runCommandAsync(`tag @s add rodio`)
		}
		if(id.includes("ambar_ore")){
			p.runCommandAsync(`tag @s add ambar`)
		}
		if(id.includes("uranium_ore")){
			p.runCommandAsync(`tag @s add uranium`)
		}
	}catch(e){
		
	}
})

world.afterEvents.playerBreakBlock.subscribe( b=>{
	try{
		let p = b.player;
		let block = b.block;

		let location = [
			b.block.location.x,
			b.block.location.y,
			b.block.location.z
			];
		let axe;


		let item = p.getComponent("inventory").container.getItem(p.selectedSlot);
		if(item){
			let lore = item.getLore()
			if(lore[0].includes("Smelthing I") && item.typeId.includes("pickaxe")){
				if(p.hasTag("copper")){
					p.removeTag("copper");
					p.runCommandAsync(`summon new:copper ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
			}
			if(lore[0].includes("Smelthing II") && item.typeId.includes("pickaxe")){
				if(p.hasTag("iron")){
					p.removeTag("iron");
					p.runCommandAsync(`summon new:iron ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
				if(p.hasTag("copper")){
					p.removeTag("copper");
					p.runCommandAsync(`summon new:copper ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
			}
			if(lore[0].includes("Smelthing III") && item.typeId.includes("pickaxe")){
				if(p.hasTag("iron")){
					p.removeTag("iron");
					p.runCommandAsync(`summon new:iron ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
				if(p.hasTag("gold")){
					p.removeTag("gold");
					p.runCommandAsync(`summon new:gold ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
				if(p.hasTag("copper")){
					p.removeTag("copper");
					p.runCommandAsync(`summon new:copper ${location[0]} ${location[1]} ${location[2]}`);
					p.runCommandAsync(`playsound fire.ignite @s`)
				}
			}
			//axe
			if (lore[0].includes("Woodcutter I")){
				axe = p.dimension.spawnEntity("new:axe", {
					x: location[0], 
					y: location[1],
					z: location[2]
				});
				axe.runCommandAsync("function enchanted_axe/axe")
				axe.runCommandAsync("function enchanted_axe/axe2")
			}
			if (lore[0].includes("Woodcutter II")){
				axe = p.dimension.spawnEntity("new:axe", {
					x: location[0], 
					y: location[1],
					z: location[2]
				});
				axe.runCommandAsync("function enchanted_axe/axe_4")
				axe.runCommandAsync("function enchanted_axe/axe2_4")
			}
			if (lore[0].includes("Woodcutter III")){
				axe = p.dimension.spawnEntity("new:axe", {
					x: location[0], 
					y: location[1],
					z: location[2]
				});
				axe.runCommandAsync("function enchanted_axe/axe_5")
				axe.runCommandAsync("function enchanted_axe/axe2_5")
			}
		}
	}
	catch(e){
	}
	
});



function enchantedLevel(enchanted_num){
	if (enchanted_num == "I"){
		return 1
	}
	else if (enchanted_num == "II"){
		return 2
	}
	else if (enchanted_num == "III"){
		return 3
	}
	else{
		return 1
	}
}

function enchant(p, item, levelid){
	try{
		let lore = ""
		let itemlore = item.getLore()[0]
		if (!itemlore){
			itemlore=""
		}
		if(item.typeId.includes("sword")){
			if (sEnchanted == 1 && !itemlore.includes("Poison")){
				lore = "\n§2Poison "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 1 && itemlore.includes("Poison")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
			if (sEnchanted == 2 && !itemlore.includes("Ice Aspect")){
				lore = "\n§3Ice Aspect "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 2 && itemlore.includes("Ice Aspect")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
			if (sEnchanted == 3 && !itemlore.includes("Levitating")){
				lore = "\n§7Levitating "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 3 && itemlore.includes("Levitating")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
			if (sEnchanted == 4 && !itemlore.includes("Vampire")){
				lore = "\n§4Vampire "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 4 && itemlore.includes("Vampire")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
			if (sEnchanted == 5 && !itemlore.includes("Wither")){
				lore = "\n§8Wither "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 5 && itemlore.includes("Wither")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
			if (sEnchanted == 6 && !itemlore.includes("Weakness")){
				lore = "\n§7Weakness "+levelid+" "
				sEnchanted = 0;
			}else if (sEnchanted == 6 && itemlore.includes("Weakness")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				sEnchanted = 0;
			}
		}
		if(item.typeId.includes("_axe")){
			if (aEnchanted == 1 && !itemlore.includes("Woodcutter")){
				lore = "\n§bWoodcutter "+levelid+" ";
				aEnchanted = 0;
			}else if (aEnchanted == 1 && itemlore.includes("Woodcutter")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 2 && !itemlore.includes("Haste")){
				lore = "\n§3Haste "+levelid+" ";
				aEnchanted = 0;
			}else if (aEnchanted == 2 && itemlore.includes("Haste")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 3 && !itemlore.includes("Poison")){
				lore = "\n§2Poison "+levelid+" "
				sEnchanted = 0;
			}else if (aEnchanted == 3 && itemlore.includes("Poison")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 4 && !itemlore.includes("Ice Aspect")){
				lore = "\n§3Ice Aspect "+levelid+" "
				aEnchanted = 0;
			}else if (aEnchanted == 4 && itemlore.includes("Ice Aspect")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 5 && !itemlore.includes("Levitating")){
				lore = "\n§7Levitating "+levelid+" "
				aEnchanted = 0;
			}else if (aEnchanted == 5 && itemlore.includes("Levitating")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 6 && !itemlore.includes("Vampire")){
				lore = "\n§4Vampire "+levelid+" "
				aEnchanted = 0;
			}else if (aEnchanted == 6 && itemlore.includes("Vampire")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 7 && !itemlore.includes("Wither")){
				lore = "\n§8Wither "+levelid+" "
				aEnchanted = 0;
			}else if (aEnchanted == 7 && itemlore.includes("Wither")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
			if (aEnchanted == 8 && !itemlore.includes("Weakness")){
				lore = "\n§7Weakness "+levelid+" "
				aEnchanted = 0;
			}else if (aEnchanted == 8 && itemlore.includes("Weakness")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				aEnchanted = 0;
			}
		}
		if(item.typeId.includes("pickaxe")){
			if (pEnchanted == 2 && !itemlore.includes("Smelthing")){
				lore = "\n§6Smelthing "+levelid+" ";
				pEnchanted = 0;
			}else if (pEnchanted == 2 && itemlore.includes("Smelthing")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				pEnchanted = 0;
			}
			if (pEnchanted == 1 && !itemlore.includes("Haste")){
				lore = "\n§3Haste "+levelid+" ";
				pEnchanted = 0;			
			}else if (pEnchanted == 1 && itemlore.includes("Haste")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
				pEnchanted = 0;
			}
		}
		if(item.typeId.includes("shovel")){
			if (!itemlore.includes("Haste")){
				lore = "\n§3Haste "+levelid+" ";

			}else if (itemlore.includes("Haste")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
			}
		}
		if(item.typeId.includes("hoe")){
			if (!itemlore.includes("Furrowing")){
				lore = "\n§3Furrowing "+levelid+" ";
			}else if (itemlore.includes("Furrowing")) {
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.repit"}]}`)
			}
		}

		if (lore != ""){
			item.setLore([itemlore + lore])
			p.getComponent("inventory").container.setItem(p.selectedSlot,item)
			if(levelid == "I"){
				p.runCommandAsync(`xp -10l @s`)
			}
			if(levelid == "II"){
				p.runCommandAsync(`xp -20l @s`)
			}
			if(levelid == "III"){
				p.runCommandAsync(`xp -30l @s`)
			}
		}
	}catch(e){
		
	}
}

function EnchantedForm(p) {
	try{
		const form = new ActionFormData()
		.title("§d§lAdvanced Enchantment Table")
		.button("§6§lSword",`textures/items/netherite_sword`)
		.button("§c§lAxe",`textures/items/diamond_axe`)
		.button("§8§lHoe",`textures/items/iron_hoe`)
		.button("§d§lPickaxe",`textures/items/stone_pickaxe`)
		.button("§e§lShovel",`textures/items/wood_shovel`)
		form.show(p).then(response => {
			p.removeTag("interact")
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if(item){
				if (!response.isCanceled && response.selection == 0) {
					if (item.typeId.includes("sword")){
						SwordEnchants(p);
					}
					if (!item.typeId.includes("sword")){
						p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
					}
				}
				if (!response.isCanceled && response.selection == 1) {
					if (item.typeId.includes("_axe") || item.typeId.includes("battleaxe")){
						AxeEnchants(p);
					}
					if (!item.typeId.includes("_axe") && !item.typeId.includes("battleaxe")){
						p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
					}
				}
				if (!response.isCanceled && response.selection == 2) {
					if (item.typeId.includes("hoe")){
						HoeEnchants(p);
					}
					if (!item.typeId.includes("hoe")){
						p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
					}
				}
				if (!response.isCanceled && response.selection == 3) {
					if (item.typeId.includes("pickaxe")){
						PickaxeEnchants(p);
					}
					if (!item.typeId.includes("pickaxe")){
						p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
					}
				}
				if (!response.isCanceled && response.selection == 4) {
					if (item.typeId.includes("shovel")){
						ShovelEnchants(p);
					}
					if (!item.typeId.includes("shovel")){
						p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
					}
				}
			}
			else if(!item && response.selection >= 0){
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.cancel"}]}`)
			}
		})
	}catch(e){
		
	}
}

let levelid = 0;

function LevelEnchanted(p){
	try{
		const levelEnchanted = new ActionFormData()
		.title("§5§lAdvanced Enchantment Table")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§2Enchant I\n10 Levels",`textures/enchanted/book`)
		.button("§l§3Enchant II\n20 Levels",`textures/enchanted/book`)
		.button("§l§5Enchant III\n30 Levels",`textures/enchanted/book`)
		levelEnchanted.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (response.selection == 1 && p.level >= 10) {	
				levelid = "I"
				enchant(p,item,levelid)
			}
			if (response.selection == 2 && p.level >= 20) {
				levelid = "II"
				enchant(p,item,levelid)
			}
			if (response.selection == 3 && p.level >= 30) {
				levelid = "III"
				enchant(p,item,levelid)
			}
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}

			if(!response.isCanceled && response.selection == 1 && p.level < 10){
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.no_xp"}]}`)
			}
			if(!response.isCanceled && response.selection == 2 && p.level < 20){
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.no_xp"}]}`)
			}
			if(!response.isCanceled && response.selection == 3 && p.level < 30){
				p.runCommandAsync(`tellraw @s {"rawtext":[{"translate":"action.enchantment.no_xp"}]}`)
			}
		})
	}catch(e){
		
	}
}

let sEnchanted = 0;
let pEnchanted = 0;
let aEnchanted = 0;

function SwordEnchants(p){
	try{
		const sword = new ActionFormData()
		.title("§5§lSword Enchantment")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§2Poison",`textures/enchanted/poison`)
		.button("§l§3Ice Aspect",`textures/enchanted/snowflake`)
		.button("§l§fLevitating",`textures/enchanted/levitacion`)
		.button("§l§4Vampire",`textures/enchanted/vampire`)
		.button("§l§0Wither",`textures/enchanted/wither`)
		.button("§l§8Weakness",`textures/enchanted/weakness`)
		sword.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}
			if (!response.isCanceled && response.selection == 1) {
				if (item.typeId.includes("sword")){
					sEnchanted = 1;
					LevelEnchanted(p);
				}
			}
			if (!response.isCanceled && response.selection == 2) {
				if (item.typeId.includes("sword")){
					sEnchanted = 2;
					LevelEnchanted(p);
				}
			}
			if (!response.isCanceled && response.selection == 3) {
				if (item.typeId.includes("sword")){
					sEnchanted = 3;
					LevelEnchanted(p);
				}
			}
			if (!response.isCanceled && response.selection == 4) {
				if (item.typeId.includes("sword")){
					sEnchanted = 4;
					LevelEnchanted(p);
				}
			}
			if (!response.isCanceled && response.selection == 5) {
				if (item.typeId.includes("sword")){
					sEnchanted = 5;
					LevelEnchanted(p);
				}
			}
			if (!response.isCanceled && response.selection == 6) {
				if (item.typeId.includes("sword")){
					sEnchanted = 6;
					LevelEnchanted(p);
				}
			}
		})
	}catch(e){
		
	}
}

function AxeEnchants(p){
	try{
		const axe = new ActionFormData()
		.title("§5§lAxe/Battleaxe Enchantment")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§9Wood Cutter",`textures/items/diamond_axe`)
		.button("§l§6Haste",`textures/enchanted/haste`)
		.button("§l§2Poison",`textures/enchanted/poison`)
		.button("§l§3Ice Aspect",`textures/enchanted/snowflake`)
		.button("§l§fLevitating",`textures/enchanted/levitacion`)
		.button("§l§4Vampire",`textures/enchanted/vampire`)
		.button("§l§0Wither",`textures/enchanted/wither`)
		.button("§l§8Weakness",`textures/enchanted/weakness`)
		axe.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}
			if (!response.isCanceled && response.selection == 1) {
				if (item.typeId.includes("axe")){
					aEnchanted = 1;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 2) {
				if (item.typeId.includes("axe")){
					aEnchanted = 2;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 3) {
				if (item.typeId.includes("axe")){
					aEnchanted = 3;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 4) {
				if (item.typeId.includes("axe")){
					aEnchanted = 4;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 5) {
				if (item.typeId.includes("axe")){
					aEnchanted = 5;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 6) {
				if (item.typeId.includes("axe")){
					aEnchanted = 6;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 7) {
				if (item.typeId.includes("axe")){
					aEnchanted = 7;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 8) {
				if (item.typeId.includes("axe")){
					aEnchanted = 8;
					LevelEnchanted(p);

				}
			}
		})
	}catch(e){
		
	}
}

function PickaxeEnchants(p){
	try{
		const pickaxe = new ActionFormData()
		.title("§5§lPickaxe Enchantment")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§3Haste",`textures/enchanted/haste`)
		.button("§l§6Smelthing",`textures/items/diamond_pickaxe`)
		pickaxe.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}
			if (!response.isCanceled && response.selection == 1) {
				if (item.typeId.includes("pickaxe")){
					pEnchanted = 1;
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 2) {
				if (item.typeId.includes("pickaxe")){
					pEnchanted = 2;
					LevelEnchanted(p);

				}
			}
		})
	}catch(e){
		
	}
}

function HoeEnchants(p){
	try{
		const hoe = new ActionFormData()
		.title("§5§lHoe Enchantment")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§bFurrowing",`textures/items/diamond_hoe`)
		hoe.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}
			if (!response.isCanceled && response.selection == 1) {
				if (item.typeId.includes("hoe")){
					LevelEnchanted(p);
				}
			}
		})
	}catch(e){
		
	}
}

function ShovelEnchants(p){
	try{
		const shovel = new ActionFormData()
		.title("§5§lShovel Enchantment")

		.button("§l§cReturn",`textures/enchanted/arrow_large`)
		.button("§l§3Haste",`textures/enchanted/haste`)
		shovel.show(p).then(response => {
			let item = p.getComponent("inventory").container.getItem(p.selectedSlot)
			if (!response.isCanceled && response.selection == 0) {
				EnchantedForm(p)
			}
			if (!response.isCanceled && response.selection == 1) {
				if (item.typeId.includes("shovel")){
					LevelEnchanted(p);

				}
			}
			if (!response.isCanceled && response.selection == 2) {
				if (item.typeId.includes("shovel")){
					LevelEnchanted(p);

				}
			}
		})
	}catch(e){
		
	}	
}